# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`singularity`](#singularity): Manage Singularity

#### Private Classes

* `singularity::config`: Private class
* `singularity::install`: Private class

## Classes

### `singularity`

Manage Singularity

#### Examples

##### 

```puppet
include ::singularity
```

#### Parameters

The following parameters are available in the `singularity` class.

##### `package_ensure`

Data type: `String`

Package ensure property

Default value: `'present'`

##### `package_name`

Data type: `String`

Singularity package name

Default value: `$singularity::params::package_name`

##### `manage_epel`

Data type: `Boolean`

Determines if EPEL repo should be managed

Default value: ``true``

##### `config_path`

Data type: `Stdlib::Absolutepath`

Path to singularity.conf

Default value: `$singularity::params::config_path`

##### `config_template`

Data type: `String`

Template used for singularity.conf

Default value: `'singularity/singularity.conf.erb'`

##### `allow_setuid`

Data type: `Enum['yes','no']`

See singularity.conf: `allow setuid`

Default value: `'yes'`

##### `max_loop_devices`

Data type: `Integer`

See singularity.conf: `max loop devices`

Default value: `256`

##### `allow_pid_ns`

Data type: `Enum['yes','no']`

See singularity.conf: `allow pid ns`

Default value: `'yes'`

##### `config_passwd`

Data type: `Enum['yes','no']`

See singularity.conf: `config passwd`

Default value: `'yes'`

##### `config_group`

Data type: `Enum['yes','no']`

See singularity.conf: `config group`

Default value: `'yes'`

##### `config_resolv_conf`

Data type: `Enum['yes','no']`

See singularity.conf: `config resolv conf`

Default value: `'yes'`

##### `mount_proc`

Data type: `Enum['yes','no']`

See singularity.conf: `mount proc`

Default value: `'yes'`

##### `mount_sys`

Data type: `Enum['yes','no']`

See singularity.conf: `mount sys`

Default value: `'yes'`

##### `mount_dev`

Data type: `Enum['yes','no']`

See singularity.conf: `mount dev`

Default value: `'yes'`

##### `mount_devpts`

Data type: `Enum['yes','no']`

See singularity.conf: `mount devpts`

Default value: `'yes'`

##### `mount_home`

Data type: `Enum['yes','no']`

See singularity.conf: `mount home`

Default value: `'yes'`

##### `mount_tmp`

Data type: `Enum['yes','no']`

See singularity.conf: `mount tmp`

Default value: `'yes'`

##### `mount_hostfs`

Data type: `Enum['yes','no']`

See singularity.conf: `mount hostfs`

Default value: `'no'`

##### `bind_paths`

Data type: `Array[Stdlib::Absolutepath]`

See singularity.conf: `bind paths`

Default value: `['/etc/localtime', '/etc/hosts']`

##### `user_bind_control`

Data type: `Enum['yes','no']`

See singularity.conf: `user bind control`

Default value: `'yes'`

##### `enable_fusemount`

Data type: `Enum['yes','no']`

See singularity.conf: `enable fusemount`

Default value: `'yes'`

##### `enable_overlay`

Data type: `Enum['yes','no','try']`

See singularity.conf: `enable overlay`

Default value: `'try'`

##### `enable_underlay`

Data type: `Enum['yes','no','try','driver']`

See singularity.conf: `enable underlay`

Default value: `'yes'`

##### `mount_slave`

Data type: `Enum['yes','no']`

See singularity.conf: `mount slave`

Default value: `'yes'`

##### `sessiondir_max_size`

Data type: `Integer`

See singularity.conf: `sessiondir max size`

Default value: `16`

##### `limit_container_owners`

Data type: `Optional[Array]`

See singularity.conf: `limit container owners`

Default value: ``undef``

##### `limit_container_groups`

Data type: `Optional[Array]`

See singularity.conf: `limit container groups`

Default value: ``undef``

##### `limit_container_paths`

Data type: `Optional[Array]`

See singularity.conf: `limit container paths`

Default value: ``undef``

##### `allow_containers`

Data type: `Hash[String,Enum['yes','no']]`

See singularity.conf: `allow containers`

Default value: `{
    'squashfs' => 'yes',
    'extfs' => 'yes',
    'dir' => 'yes',
    'encrypted' => 'yes',
  }`

##### `always_use_nv`

Data type: `Enum['yes','no']`

See singularity.conf: `always use nv`

Default value: `'no'`

##### `always_use_rocm`

Data type: `Enum['yes','no']`

See singularity.conf: `always use rocm`

Default value: `'no'`

##### `root_default_capabilities`

Data type: `Enum['full','file','default','no']`

See singularity.conf: `root default capabilities`

Default value: `'full'`

##### `memory_fs_type`

Data type: `Enum['tmpfs','ramfs']`

See singularity.conf: `memory fs type`

Default value: `'tmpfs'`

##### `cni_configuration_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `cni configuration path`

Default value: ``undef``

##### `cni_plugin_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `cni plugin path`

Default value: ``undef``

##### `mksquashfs_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `mksquashfs path`

Default value: ``undef``

##### `mksquashfs_procs`

Data type: `Integer[0,default]`

See singularity.conf: `mksquashfs procs`

Default value: `0`

##### `mksquashfs_mem`

Data type: `Optional[String[1]]`

See singularity.conf: `mksquashfs mem`

Default value: ``undef``

##### `cryptsetup_path`

Data type: `Optional[Stdlib::Absolutepath]`

See singularity.conf: `cryptsetup path`

Default value: ``undef``

##### `shared_loop_devices`

Data type: `Enum['yes','no']`

See singularity.conf: `shared loop devices`

Default value: `'no'`

##### `image_driver`

Data type: `Optional[String]`

See singularity.conf: `image driver`

Default value: ``undef``

##### `namespace_users`

Data type: `Array`

List of uses to add to /etc/subuid and /etc/subgid to support user namespaces

Default value: `[]`

##### `namespace_begin_id`

Data type: `Integer`

The beginning ID for /etc/subuid and /etc/subgid. The value is incremented
For each user by start + namespace_id_range + 1

Default value: `65537`

##### `namespace_id_range`

Data type: `Integer`

The range of UIDs/GIDs usable by a user in namespaces

Default value: `65536`

##### `subid_template`

Data type: `String`

The template to use for /etc/subuid and /etc/subgid

Default value: `'singularity/subid.erb'`

